@@ -53,7 +53,7 @@ func (b *deploymentBuilder) Do(ctx context.Context) error {
 
 	// if proxy injection is requested, get the proxy values and use them
 	if containerNamesString := deployment.Annotations["config.openshift.io/inject-proxy"]; len(containerNamesString) > 0 {
-		proxyConfig, err := b.proxyGetter.Proxies().Get("cluster", metav1.GetOptions{})
+		proxyConfig, err := b.proxyGetter.Proxies().Get(ctx, "cluster", metav1.GetOptions{})
 		// not found just means that we don't have proxy configuration, so we should tolerate and fill in empty
 		if err != nil && !errors.IsNotFound(err) {
 			return err
@@ -70,7 +70,7 @@ func (b *deploymentBuilder) Do(ctx context.Context) error {
 		}
 	}
 
-	actual, updated, err := resourceapply.ApplyDeployment(b.client, deployment)
+	actual, updated, err := resourceapply.ApplyDeployment(ctx, b.client, deployment)
 	if err != nil {
 		return err
 	}
@@ -79,11 +79,12 @@ func (b *deploymentBuilder) Do(ctx context.Context) error {
 	}
 	return nil
 }
+
 func waitForDeploymentCompletion(ctx context.Context, client appsclientv1.DeploymentsGetter, deployment *appsv1.Deployment) error {
 	iden := fmt.Sprintf("%s/%s", deployment.Namespace, deployment.Name)
 	var lastErr error
 	err := wait.PollImmediateUntil(defaultObjectPollInterval, func() (bool, error) {
-		d, err := client.Deployments(deployment.Namespace).Get(deployment.Name, metav1.GetOptions{})
+		d, err := client.Deployments(deployment.Namespace).Get(ctx, deployment.Name, metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			// exit early to recreate the deployment.
 			return false, err
@@ -201,7 +202,7 @@ func (b *daemonsetBuilder) Do(ctx context.Context) error {
 
 	// if proxy injection is requested, get the proxy values and use them
 	if containerNamesString := daemonset.Annotations["config.openshift.io/inject-proxy"]; len(containerNamesString) > 0 {
-		proxyConfig, err := b.proxyGetter.Proxies().Get("cluster", metav1.GetOptions{})
+		proxyConfig, err := b.proxyGetter.Proxies().Get(ctx, "cluster", metav1.GetOptions{})
 		// not found just means that we don't have proxy configuration, so we should tolerate and fill in empty
 		if err != nil && !errors.IsNotFound(err) {
 			return err
@@ -218,7 +219,7 @@ func (b *daemonsetBuilder) Do(ctx context.Context) error {
 		}
 	}
 
-	actual, updated, err := resourceapply.ApplyDaemonSet(b.client, daemonset)
+	actual, updated, err := resourceapply.ApplyDaemonSet(ctx, b.client, daemonset)
 	if err != nil {
 		return err
 	}
@@ -232,7 +233,7 @@ func waitForDaemonsetRollout(ctx context.Context, client appsclientv1.DaemonSets
 	iden := fmt.Sprintf("%s/%s", daemonset.Namespace, daemonset.Name)
 	var lastErr error
 	err := wait.PollImmediateUntil(defaultObjectPollInterval, func() (bool, error) {
-		d, err := client.DaemonSets(daemonset.Namespace).Get(daemonset.Name, metav1.GetOptions{})
+		d, err := client.DaemonSets(daemonset.Namespace).Get(ctx, daemonset.Name, metav1.GetOptions{})
 		if errors.IsNotFound(err) {
 			// exit early to recreate the daemonset.
 			return false, err
